# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: session/v1/session.proto
# Protobuf Python Version: 5.27.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    4,
    '',
    'session/v1/session.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from common.v1 import types_pb2 as common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18session/v1/session.proto\x12\x18servicebridge.session.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x15\x63ommon/v1/types.proto\"\xcb\x0b\n\x08\x45nvelope\x12\x10\n\x03seq\x18\x01 \x01(\x04R\x03seq\x12\x17\n\x07\x61\x63k_seq\x18\x02 \x01(\x04R\x06\x61\x63kSeq\x12!\n\x0ctimestamp_ms\x18\x03 \x01(\x03R\x0btimestampMs\x12\x37\n\x05hello\x18\n \x01(\x0b\x32\x1f.servicebridge.session.v1.HelloH\x00R\x05hello\x12\x41\n\thello_ack\x18\x0b \x01(\x0b\x32\".servicebridge.session.v1.HelloAckH\x00R\x08helloAck\x12=\n\x05\x64rain\x18\x0c \x01(\x0b\x32%.servicebridge.session.v1.DrainSignalH\x00R\x05\x64rain\x12@\n\x06goaway\x18\r \x01(\x0b\x32&.servicebridge.session.v1.GoawaySignalH\x00R\x06goaway\x12\x39\n\x04ping\x18\x14 \x01(\x0b\x32#.servicebridge.session.v1.PingFrameH\x00R\x04ping\x12\x39\n\x04pong\x18\x15 \x01(\x0b\x32#.servicebridge.session.v1.PongFrameH\x00R\x04pong\x12P\n\x0e\x63ommand_result\x18\x1e \x01(\x0b\x32\'.servicebridge.session.v1.CommandResultH\x00R\rcommandResult\x12H\n\ttelemetry\x18\x1f \x01(\x0b\x32(.servicebridge.session.v1.TelemetryFrameH\x00R\ttelemetry\x12R\n\rstream_append\x18  \x01(\x0b\x32+.servicebridge.session.v1.StreamAppendFrameH\x00R\x0cstreamAppend\x12R\n\rworker_status\x18! \x01(\x0b\x32+.servicebridge.session.v1.WorkerStatusFrameH\x00R\x0cworkerStatus\x12S\n\x0fposition_update\x18\" \x01(\x0b\x32(.servicebridge.session.v1.PositionUpdateH\x00R\x0epositionUpdate\x12G\n\x08\x64ispatch\x18( \x01(\x0b\x32).servicebridge.session.v1.DispatchCommandH\x00R\x08\x64ispatch\x12G\n\x0b\x63onfig_push\x18) \x01(\x0b\x32$.servicebridge.session.v1.ConfigPushH\x00R\nconfigPush\x12J\n\x0cpermit_grant\x18\x32 \x01(\x0b\x32%.servicebridge.session.v1.PermitGrantH\x00R\x0bpermitGrant\x12P\n\x0epermit_release\x18\x33 \x01(\x0b\x32\'.servicebridge.session.v1.PermitReleaseH\x00R\rpermitRelease\x12N\n\x0b\x66low_update\x18\x34 \x01(\x0b\x32+.servicebridge.session.v1.FlowControlUpdateH\x00R\nflowUpdate\x12S\n\x0fpublish_message\x18\x35 \x01(\x0b\x32(.servicebridge.session.v1.PublishMessageH\x00R\x0epublishMessage\x12G\n\x0bpublish_ack\x18\x36 \x01(\x0b\x32$.servicebridge.session.v1.PublishAckH\x00R\npublishAck\x12<\n\x05\x65rror\x18\x63 \x01(\x0b\x32$.servicebridge.session.v1.ErrorFrameH\x00R\x05\x65rrorB\t\n\x07payload\"\xf7\x03\n\x05Hello\x12\x43\n\x08identity\x18\x01 \x01(\x0b\x32\'.servicebridge.common.v1.WorkerIdentityR\x08identity\x12!\n\x0cmax_inflight\x18\x02 \x01(\x05R\x0bmaxInflight\x12!\n\x0cmin_inflight\x18\x03 \x01(\x05R\x0bminInflight\x12!\n\x0cresume_token\x18\x04 \x01(\tR\x0bresumeToken\x12\x14\n\x05\x65poch\x18\x05 \x01(\x04R\x05\x65poch\x12*\n\x11last_received_seq\x18\x06 \x01(\x04R\x0flastReceivedSeq\x12\"\n\rlast_sent_seq\x18\x07 \x01(\x04R\x0blastSentSeq\x12\x32\n\x15\x63ompleted_command_ids\x18\x08 \x03(\tR\x13\x63ompletedCommandIds\x12\x1f\n\x0bsdk_version\x18\n \x01(\tR\nsdkVersion\x12\"\n\x0c\x63\x61pabilities\x18\x0b \x03(\tR\x0c\x63\x61pabilities\x12\x12\n\x04zone\x18\x0c \x01(\tR\x04zone\x12M\n\x0etransport_mode\x18\r \x01(\x0e\x32&.servicebridge.common.v1.TransportModeR\rtransportMode\"\xec\x04\n\x08HelloAck\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12!\n\x0cresume_token\x18\x02 \x01(\tR\x0bresumeToken\x12\x14\n\x05\x65poch\x18\x03 \x01(\x04R\x05\x65poch\x12\x18\n\x07resumed\x18\x04 \x01(\x08R\x07resumed\x12&\n\x0fresume_from_seq\x18\x05 \x01(\x04R\rresumeFromSeq\x12+\n\x11replayed_commands\x18\x06 \x01(\x05R\x10replayedCommands\x12-\n\x12reconciled_results\x18\x07 \x01(\x05R\x11reconciledResults\x12\x32\n\x15heartbeat_interval_ms\x18\n \x01(\x05R\x13heartbeatIntervalMs\x12\x30\n\x14heartbeat_timeout_ms\x18\x0b \x01(\x05R\x12heartbeatTimeoutMs\x12\'\n\x0finitial_permits\x18\x0c \x01(\x05R\x0einitialPermits\x12\x1f\n\x0bmax_permits\x18\r \x01(\x05R\nmaxPermits\x12`\n\x18\x65\x66\x66\x65\x63tive_transport_mode\x18\x14 \x01(\x0e\x32&.servicebridge.common.v1.TransportModeR\x16\x65\x66\x66\x65\x63tiveTransportMode\x12X\n\x12resume_fail_reason\x18\x1e \x01(\x0e\x32*.servicebridge.session.v1.ResumeFailReasonR\x10resumeFailReason\"v\n\x0b\x44rainSignal\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x12\x1f\n\x0b\x64\x65\x61\x64line_ms\x18\x02 \x01(\x05R\ndeadlineMs\x12.\n\x13pending_command_ids\x18\x03 \x03(\tR\x11pendingCommandIds\"`\n\x0cGoawaySignal\x12\x38\n\x04\x63ode\x18\x01 \x01(\x0e\x32$.servicebridge.session.v1.GoawayCodeR\x04\x63ode\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\".\n\tPingFrame\x12!\n\x0ctimestamp_ms\x18\x01 \x01(\x03R\x0btimestampMs\"g\n\tPongFrame\x12*\n\x11\x65\x63ho_timestamp_ms\x18\x01 \x01(\x03R\x0f\x65\x63hoTimestampMs\x12.\n\x13server_timestamp_ms\x18\x02 \x01(\x03R\x11serverTimestampMs\"\xbf\x03\n\x0bTaskCommand\x12>\n\x04type\x18\x01 \x01(\x0e\x32*.servicebridge.session.v1.TaskCommand.TypeR\x04type\x12\x19\n\x08trace_id\x18\x02 \x01(\tR\x07traceId\x12\x17\n\x07span_id\x18\x03 \x01(\tR\x06spanId\x12$\n\x0eparent_span_id\x18\x04 \x01(\tR\x0cparentSpanId\x12\x18\n\x07payload\x18\x05 \x01(\x0cR\x07payload\x12\x43\n\x04meta\x18\x06 \x03(\x0b\x32/.servicebridge.session.v1.TaskCommand.MetaEntryR\x04meta\x12(\n\x10\x64\x65\x61\x64line_unix_ms\x18\x07 \x01(\x03R\x0e\x64\x65\x61\x64lineUnixMs\x12\x18\n\x07\x61ttempt\x18\x08 \x01(\x05R\x07\x61ttempt\x1a\x37\n\tMetaEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\":\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08TYPE_RPC\x10\x01\x12\x0e\n\nTYPE_EVENT\x10\x02\"\xbd\x02\n\x0f\x44ispatchCommand\x12\x1d\n\ncommand_id\x18\x01 \x01(\tR\tcommandId\x12(\n\x10\x64\x65\x61\x64line_unix_ms\x18\x02 \x01(\x03R\x0e\x64\x65\x61\x64lineUnixMs\x12\x1b\n\tis_replay\x18\x03 \x01(\x08R\x08isReplay\x12H\n\x0ctask_command\x18\x14 \x01(\x0b\x32%.servicebridge.session.v1.TaskCommandR\x0btaskCommand\x12\x35\n\x03rpc\x18\n \x01(\x0b\x32!.servicebridge.session.v1.RpcTaskH\x00R\x03rpc\x12;\n\x05\x65vent\x18\x0b \x01(\x0b\x32#.servicebridge.session.v1.EventTaskH\x00R\x05\x65ventB\x06\n\x04task\"\xb3\x01\n\x07RpcTask\x12\x0e\n\x02\x66n\x18\x01 \x01(\tR\x02\x66n\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\x12$\n\x0egroup_trace_id\x18\x03 \x01(\tR\x0cgroupTraceId\x12\x17\n\x07span_id\x18\x04 \x01(\tR\x06spanId\x12\x19\n\x08trace_id\x18\x05 \x01(\tR\x07traceId\x12$\n\x0eparent_span_id\x18\x06 \x01(\tR\x0cparentSpanId\"\x82\x03\n\tEventTask\x12\x1d\n\nmessage_id\x18\x01 \x01(\tR\tmessageId\x12\x1d\n\ngroup_name\x18\x02 \x01(\tR\tgroupName\x12\x14\n\x05topic\x18\x03 \x01(\tR\x05topic\x12\x18\n\x07payload\x18\x04 \x01(\x0cR\x07payload\x12J\n\x07headers\x18\x05 \x03(\x0b\x32\x30.servicebridge.session.v1.EventTask.HeadersEntryR\x07headers\x12$\n\x0egroup_trace_id\x18\x06 \x01(\tR\x0cgroupTraceId\x12$\n\x0eparent_span_id\x18\x07 \x01(\tR\x0cparentSpanId\x12\x18\n\x07\x61ttempt\x18\x08 \x01(\x05R\x07\x61ttempt\x12\x19\n\x08trace_id\x18\t \x01(\tR\x07traceId\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xf2\x01\n\rCommandResult\x12\x1d\n\ncommand_id\x18\x01 \x01(\tR\tcommandId\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12\x16\n\x06output\x18\x03 \x01(\x0cR\x06output\x12\x14\n\x05\x65rror\x18\x04 \x01(\tR\x05\x65rror\x12\x10\n\x03\x61\x63k\x18\x05 \x01(\x08R\x03\x61\x63k\x12$\n\x0eretry_after_ms\x18\x06 \x01(\x05R\x0cretryAfterMs\x12#\n\rreject_reason\x18\x07 \x01(\tR\x0crejectReason\x12\x1d\n\nresult_seq\x18\x08 \x01(\x04R\tresultSeq\"\x83\x01\n\x0eTelemetryFrame\x12\x39\n\x05spans\x18\x01 \x03(\x0b\x32#.servicebridge.session.v1.SpanEventR\x05spans\x12\x36\n\x04logs\x18\x02 \x03(\x0b\x32\".servicebridge.session.v1.LogEntryR\x04logs\"\xee\x03\n\tSpanEvent\x12<\n\x04kind\x18\x01 \x01(\x0e\x32(.servicebridge.session.v1.SpanEvent.KindR\x04kind\x12\x19\n\x08trace_id\x18\x02 \x01(\tR\x07traceId\x12\x17\n\x07span_id\x18\x03 \x01(\tR\x06spanId\x12$\n\x0eparent_span_id\x18\x04 \x01(\tR\x0cparentSpanId\x12\x0e\n\x02\x66n\x18\x05 \x01(\tR\x02\x66n\x12\x1d\n\nstarted_at\x18\x06 \x01(\x03R\tstartedAt\x12\x1f\n\x0b\x64uration_ms\x18\x07 \x01(\x03R\ndurationMs\x12\x18\n\x07success\x18\x08 \x01(\x08R\x07success\x12\x14\n\x05\x65rror\x18\t \x01(\tR\x05\x65rror\x12\x14\n\x05input\x18\n \x01(\x0cR\x05input\x12\x16\n\x06output\x18\x0b \x01(\x0cR\x06output\x12\x18\n\x07\x61ttempt\x18\x0c \x01(\x05R\x07\x61ttempt\x12\x1b\n\tspan_type\x18\r \x01(\tR\x08spanType\x12%\n\x0etarget_service\x18\x0e \x01(\tR\rtargetService\"=\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x0e\n\nKIND_START\x10\x01\x12\x0f\n\x0bKIND_FINISH\x10\x02\"\xe8\x02\n\x08LogEntry\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\x12\x17\n\x07span_id\x18\x02 \x01(\tR\x06spanId\x12!\n\x0cservice_name\x18\x03 \x01(\tR\x0bserviceName\x12\x14\n\x05level\x18\x04 \x01(\tR\x05level\x12\x18\n\x07message\x18\x05 \x01(\tR\x07message\x12!\n\x0ctimestamp_ns\x18\x06 \x01(\x03R\x0btimestampNs\x12R\n\nattributes\x18\x07 \x03(\x0b\x32\x32.servicebridge.session.v1.LogEntry.AttributesEntryR\nattributes\x12\x1f\n\x0binstance_id\x18\x08 \x01(\tR\ninstanceId\x1a=\n\x0f\x41ttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x96\x01\n\x11StreamAppendFrame\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x1d\n\nevent_type\x18\x03 \x01(\tR\teventType\x12\x12\n\x04\x64\x61ta\x18\x04 \x01(\x0cR\x04\x64\x61ta\x12!\n\x0ctrace_status\x18\x05 \x01(\tR\x0btraceStatus\"\xc3\x01\n\x11WorkerStatusFrame\x12%\n\x0e\x66unction_names\x18\x01 \x03(\tR\rfunctionNames\x12\x1f\n\x0bgroup_names\x18\x02 \x03(\tR\ngroupNames\x12\x1a\n\x08\x65ndpoint\x18\x03 \x01(\tR\x08\x65ndpoint\x12\x1f\n\x0b\x63pu_percent\x18\x04 \x01(\x02R\ncpuPercent\x12\x15\n\x06ram_mb\x18\x05 \x01(\x05R\x05ramMb\x12\x12\n\x04zone\x18\x06 \x01(\tR\x04zone\"a\n\x0bPermitGrant\x12-\n\x12\x61\x64\x64itional_permits\x18\x01 \x01(\x05R\x11\x61\x64\x64itionalPermits\x12#\n\rtotal_pending\x18\x02 \x01(\x05R\x0ctotalPending\"+\n\rPermitRelease\x12\x1a\n\x08released\x18\x01 \x01(\x05R\x08released\"S\n\x11\x46lowControlUpdate\x12&\n\x0fnew_window_size\x18\x01 \x01(\x05R\rnewWindowSize\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"<\n\x0ePositionUpdate\x12*\n\x11last_received_seq\x18\x01 \x01(\x04R\x0flastReceivedSeq\"b\n\nConfigPush\x12T\n\x10transport_config\x18\x01 \x01(\x0b\x32).servicebridge.session.v1.TransportConfigR\x0ftransportConfig\"\xd1\x05\n\x0fTransportConfig\x12I\n\x0c\x64\x65\x66\x61ult_mode\x18\x01 \x01(\x0e\x32&.servicebridge.common.v1.TransportModeR\x0b\x64\x65\x66\x61ultMode\x12l\n\x11service_overrides\x18\x02 \x03(\x0b\x32?.servicebridge.session.v1.TransportConfig.ServiceOverridesEntryR\x10serviceOverrides\x12o\n\x12\x66unction_overrides\x18\x03 \x03(\x0b\x32@.servicebridge.session.v1.TransportConfig.FunctionOverridesEntryR\x11\x66unctionOverrides\x12\x66\n\x17\x64\x65\x66\x61ult_circuit_breaker\x18\x04 \x01(\x0b\x32..servicebridge.session.v1.CircuitBreakerConfigR\x15\x64\x65\x66\x61ultCircuitBreaker\x12\x38\n\x04zone\x18\x05 \x01(\x0b\x32$.servicebridge.session.v1.ZoneConfigR\x04zone\x1aw\n\x15ServiceOverridesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.servicebridge.session.v1.ServiceTransportOverrideR\x05value:\x02\x38\x01\x1ay\n\x16\x46unctionOverridesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12I\n\x05value\x18\x02 \x01(\x0b\x32\x33.servicebridge.session.v1.FunctionTransportOverrideR\x05value:\x02\x38\x01\"\xf9\x02\n\x18ServiceTransportOverride\x12:\n\x04mode\x18\x01 \x01(\x0e\x32&.servicebridge.common.v1.TransportModeR\x04mode\x12Q\n\x0f\x66\x61llback_policy\x18\x02 \x01(\x0e\x32(.servicebridge.session.v1.FallbackPolicyR\x0e\x66\x61llbackPolicy\x12*\n\x11\x64irect_timeout_ms\x18\x03 \x01(\x05R\x0f\x64irectTimeoutMs\x12I\n\tlb_policy\x18\x04 \x01(\x0e\x32,.servicebridge.common.v1.LoadBalancingPolicyR\x08lbPolicy\x12W\n\x0f\x63ircuit_breaker\x18\x05 \x01(\x0b\x32..servicebridge.session.v1.CircuitBreakerConfigR\x0e\x63ircuitBreaker\"\xc9\x01\n\x19\x46unctionTransportOverride\x12:\n\x04mode\x18\x01 \x01(\x0e\x32&.servicebridge.common.v1.TransportModeR\x04mode\x12Q\n\x0f\x66\x61llback_policy\x18\x02 \x01(\x0e\x32(.servicebridge.session.v1.FallbackPolicyR\x0e\x66\x61llbackPolicy\x12\x1d\n\ntimeout_ms\x18\x03 \x01(\x05R\ttimeoutMs\"\xcf\x01\n\x14\x43ircuitBreakerConfig\x12+\n\x11\x66\x61ilure_threshold\x18\x01 \x01(\x05R\x10\x66\x61ilureThreshold\x12+\n\x11success_threshold\x18\x02 \x01(\x05R\x10successThreshold\x12(\n\x10open_duration_ms\x18\x03 \x01(\x05R\x0eopenDurationMs\x12\x33\n\x16half_open_max_requests\x18\x04 \x01(\x05R\x13halfOpenMaxRequests\"x\n\nZoneConfig\x12\x1d\n\nlocal_zone\x18\x01 \x01(\tR\tlocalZone\x12\x1f\n\x0bprefer_zone\x18\x02 \x01(\x08R\npreferZone\x12*\n\x11zone_weight_boost\x18\x03 \x01(\x05R\x0fzoneWeightBoost\"~\n\nErrorFrame\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1c\n\tretryable\x18\x03 \x01(\x08R\tretryable\x12$\n\x0eretry_after_ms\x18\x04 \x01(\x05R\x0cretryAfterMs\"\xad\x02\n\x0ePublishMessage\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x14\n\x05topic\x18\x02 \x01(\tR\x05topic\x12\x18\n\x07payload\x18\x03 \x01(\x0cR\x07payload\x12O\n\x07headers\x18\x04 \x03(\x0b\x32\x35.servicebridge.session.v1.PublishMessage.HeadersEntryR\x07headers\x12\x19\n\x08trace_id\x18\x05 \x01(\tR\x07traceId\x12$\n\x0eparent_span_id\x18\x06 \x01(\tR\x0cparentSpanId\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"`\n\nPublishAck\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror*\xec\x01\n\x10ResumeFailReason\x12\x1b\n\x17RESUME_FAIL_UNSPECIFIED\x10\x00\x12\x1d\n\x19RESUME_FAIL_TOKEN_EXPIRED\x10\x01\x12\x1d\n\x19RESUME_FAIL_TOKEN_INVALID\x10\x02\x12\x1d\n\x19RESUME_FAIL_GAP_TOO_LARGE\x10\x03\x12\x1e\n\x1aRESUME_FAIL_EPOCH_MISMATCH\x10\x04\x12\x1e\n\x1aRESUME_FAIL_SESSION_FENCED\x10\x05\x12\x1e\n\x1aRESUME_FAIL_SERVER_RESTART\x10\x06*\x80\x01\n\nGoawayCode\x12\x12\n\x0eGOAWAY_UNKNOWN\x10\x00\x12\x1c\n\x18GOAWAY_GRACEFUL_SHUTDOWN\x10\x01\x12\x15\n\x11GOAWAY_OVERLOADED\x10\x02\x12\x11\n\rGOAWAY_FENCED\x10\x03\x12\x16\n\x12GOAWAY_MAINTENANCE\x10\x04*l\n\x0e\x46\x61llbackPolicy\x12\x11\n\rFALLBACK_NONE\x10\x00\x12\x15\n\x11\x46\x41LLBACK_TO_PROXY\x10\x01\x12\x16\n\x12\x46\x41LLBACK_TO_DIRECT\x10\x02\x12\x18\n\x14\x46\x41LLBACK_BEST_EFFORT\x10\x03\x32g\n\x0eSessionService\x12U\n\x07\x43hannel\x12\".servicebridge.session.v1.Envelope\x1a\".servicebridge.session.v1.Envelope(\x01\x30\x01\x42\x45ZCgithub.com/servicebridge/server-go/internal/pb/session/v1;sessionv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'session.v1.session_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/servicebridge/server-go/internal/pb/session/v1;sessionv1'
  _globals['_TASKCOMMAND_METAENTRY']._loaded_options = None
  _globals['_TASKCOMMAND_METAENTRY']._serialized_options = b'8\001'
  _globals['_EVENTTASK_HEADERSENTRY']._loaded_options = None
  _globals['_EVENTTASK_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._loaded_options = None
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._loaded_options = None
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHMESSAGE_HEADERSENTRY']._loaded_options = None
  _globals['_PUBLISHMESSAGE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_RESUMEFAILREASON']._serialized_start=8585
  _globals['_RESUMEFAILREASON']._serialized_end=8821
  _globals['_GOAWAYCODE']._serialized_start=8824
  _globals['_GOAWAYCODE']._serialized_end=8952
  _globals['_FALLBACKPOLICY']._serialized_start=8954
  _globals['_FALLBACKPOLICY']._serialized_end=9062
  _globals['_ENVELOPE']._serialized_start=107
  _globals['_ENVELOPE']._serialized_end=1590
  _globals['_HELLO']._serialized_start=1593
  _globals['_HELLO']._serialized_end=2096
  _globals['_HELLOACK']._serialized_start=2099
  _globals['_HELLOACK']._serialized_end=2719
  _globals['_DRAINSIGNAL']._serialized_start=2721
  _globals['_DRAINSIGNAL']._serialized_end=2839
  _globals['_GOAWAYSIGNAL']._serialized_start=2841
  _globals['_GOAWAYSIGNAL']._serialized_end=2937
  _globals['_PINGFRAME']._serialized_start=2939
  _globals['_PINGFRAME']._serialized_end=2985
  _globals['_PONGFRAME']._serialized_start=2987
  _globals['_PONGFRAME']._serialized_end=3090
  _globals['_TASKCOMMAND']._serialized_start=3093
  _globals['_TASKCOMMAND']._serialized_end=3540
  _globals['_TASKCOMMAND_METAENTRY']._serialized_start=3425
  _globals['_TASKCOMMAND_METAENTRY']._serialized_end=3480
  _globals['_TASKCOMMAND_TYPE']._serialized_start=3482
  _globals['_TASKCOMMAND_TYPE']._serialized_end=3540
  _globals['_DISPATCHCOMMAND']._serialized_start=3543
  _globals['_DISPATCHCOMMAND']._serialized_end=3860
  _globals['_RPCTASK']._serialized_start=3863
  _globals['_RPCTASK']._serialized_end=4042
  _globals['_EVENTTASK']._serialized_start=4045
  _globals['_EVENTTASK']._serialized_end=4431
  _globals['_EVENTTASK_HEADERSENTRY']._serialized_start=4373
  _globals['_EVENTTASK_HEADERSENTRY']._serialized_end=4431
  _globals['_COMMANDRESULT']._serialized_start=4434
  _globals['_COMMANDRESULT']._serialized_end=4676
  _globals['_TELEMETRYFRAME']._serialized_start=4679
  _globals['_TELEMETRYFRAME']._serialized_end=4810
  _globals['_SPANEVENT']._serialized_start=4813
  _globals['_SPANEVENT']._serialized_end=5307
  _globals['_SPANEVENT_KIND']._serialized_start=5246
  _globals['_SPANEVENT_KIND']._serialized_end=5307
  _globals['_LOGENTRY']._serialized_start=5310
  _globals['_LOGENTRY']._serialized_end=5670
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_start=5609
  _globals['_LOGENTRY_ATTRIBUTESENTRY']._serialized_end=5670
  _globals['_STREAMAPPENDFRAME']._serialized_start=5673
  _globals['_STREAMAPPENDFRAME']._serialized_end=5823
  _globals['_WORKERSTATUSFRAME']._serialized_start=5826
  _globals['_WORKERSTATUSFRAME']._serialized_end=6021
  _globals['_PERMITGRANT']._serialized_start=6023
  _globals['_PERMITGRANT']._serialized_end=6120
  _globals['_PERMITRELEASE']._serialized_start=6122
  _globals['_PERMITRELEASE']._serialized_end=6165
  _globals['_FLOWCONTROLUPDATE']._serialized_start=6167
  _globals['_FLOWCONTROLUPDATE']._serialized_end=6250
  _globals['_POSITIONUPDATE']._serialized_start=6252
  _globals['_POSITIONUPDATE']._serialized_end=6312
  _globals['_CONFIGPUSH']._serialized_start=6314
  _globals['_CONFIGPUSH']._serialized_end=6412
  _globals['_TRANSPORTCONFIG']._serialized_start=6415
  _globals['_TRANSPORTCONFIG']._serialized_end=7136
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._serialized_start=6894
  _globals['_TRANSPORTCONFIG_SERVICEOVERRIDESENTRY']._serialized_end=7013
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._serialized_start=7015
  _globals['_TRANSPORTCONFIG_FUNCTIONOVERRIDESENTRY']._serialized_end=7136
  _globals['_SERVICETRANSPORTOVERRIDE']._serialized_start=7139
  _globals['_SERVICETRANSPORTOVERRIDE']._serialized_end=7516
  _globals['_FUNCTIONTRANSPORTOVERRIDE']._serialized_start=7519
  _globals['_FUNCTIONTRANSPORTOVERRIDE']._serialized_end=7720
  _globals['_CIRCUITBREAKERCONFIG']._serialized_start=7723
  _globals['_CIRCUITBREAKERCONFIG']._serialized_end=7930
  _globals['_ZONECONFIG']._serialized_start=7932
  _globals['_ZONECONFIG']._serialized_end=8052
  _globals['_ERRORFRAME']._serialized_start=8054
  _globals['_ERRORFRAME']._serialized_end=8180
  _globals['_PUBLISHMESSAGE']._serialized_start=8183
  _globals['_PUBLISHMESSAGE']._serialized_end=8484
  _globals['_PUBLISHMESSAGE_HEADERSENTRY']._serialized_start=4373
  _globals['_PUBLISHMESSAGE_HEADERSENTRY']._serialized_end=4431
  _globals['_PUBLISHACK']._serialized_start=8486
  _globals['_PUBLISHACK']._serialized_end=8582
  _globals['_SESSIONSERVICE']._serialized_start=9064
  _globals['_SESSIONSERVICE']._serialized_end=9167
# @@protoc_insertion_point(module_scope)
