# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: servicebridge.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'servicebridge.proto'
)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13servicebridge.proto\x12\rservicebridge"O\n\rHandleRequest\x12\n\n\x02fn\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08trace_id\x18\x03 \x01(\t\x12\x0f\n\x07span_id\x18\x04 \x01(\t"@\n\x0eHandleResponse\x12\x0e\n\x06output\x18\x01 \x01(\x0c\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\r\n\x05error\x18\x03 \x01(\t"\x8e\x02\n\x15DeliverMessageRequest\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12B\n\x07headers\x18\x05 \x03(\x0b21.servicebridge.DeliverMessageRequest.HeadersEntry\x12\x10\n\x08trace_id\x18\x06 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x07 \x01(\t\x12\x0f\n\x07attempt\x18\x08 \x01(\x05\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"\xfa\x01\n\x0ePublishRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12;\n\x07headers\x18\x03 \x03(\x0b2*.servicebridge.PublishRequest.HeadersEntry\x12\x10\n\x08trace_id\x18\x04 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x05 \x01(\t\x12\x18\n\x10producer_service\x18\x06 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x07 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"%\n\x0fPublishResponse\x12\x12\n\nmessage_id\x18\x01 \x01(\t"X\n\x0bDeliveryAck\x12\x0b\n\x03ack\x18\x01 \x01(\x08\x12\x16\n\x0eretry_after_ms\x18\x02 \x01(\x05\x12\x15\n\rreject_reason\x18\x03 \x01(\t\x12\r\n\x05error\x18\x04 \x01(\t".\n\x14WatchRegistryRequest\x12\x16\n\x0efunction_names\x18\x01 \x03(\t"(\n\x15LookupFunctionRequest\x12\x0f\n\x07fn_name\x18\x01 \x01(\t"o\n\x16LookupFunctionResponse\x12\r\n\x05found\x18\x01 \x01(\x08\x12\x16\n\x0ecanonical_name\x18\x02 \x01(\t\x12.\n\tendpoints\x18\x03 \x01(\x0b2\x1b.servicebridge.EndpointList"\xb1\x01\n\x0fRegistryMessage\x120\n\x04kind\x18\x01 \x01(\x0e2".servicebridge.RegistryMessageKind\x12\x10\n\x08revision\x18\x02 \x01(\x03\x12-\n\x04full\x18\x03 \x01(\x0b2\x1f.servicebridge.RegistrySnapshot\x12+\n\x05delta\x18\x04 \x01(\x0b2\x1c.servicebridge.RegistryDelta"\xaa\x01\n\rRegistryDelta\x12:\n\x07upserts\x18\x01 \x03(\x0b2).servicebridge.RegistryDelta.UpsertsEntry\x12\x10\n\x08removals\x18\x02 \x03(\t\x1aK\n\x0cUpsertsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b2\x1b.servicebridge.EndpointList:\x028\x01"Z\n\x0eWorkerEndpoint\x12\x10\n\x08endpoint\x18\x01 \x01(\t\x12\x11\n\ttransport\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x0e\n\x06weight\x18\x04 \x01(\x05"\x92\x01\n\x10RegistrySnapshot\x125\n\x03rpc\x18\x01 \x03(\x0b2(.servicebridge.RegistrySnapshot.RpcEntry\x1aG\n\x08RpcEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b2\x1b.servicebridge.EndpointList:\x028\x01"\x96\x01\n\x0cEndpointList\x120\n\tendpoints\x18\x01 \x03(\x0b2\x1d.servicebridge.WorkerEndpoint\x12\x19\n\x11input_schema_json\x18\x02 \x01(\t\x12\x1a\n\x12output_schema_json\x18\x03 \x01(\t\x12\x17\n\x0fallowed_callers\x18\x04 \x03(\tJ\x04\x08\x05\x10\x08"\xbe\x01\n\x16ReportCallStartRequest\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\n\n\x02fn\x18\x03 \x01(\t\x12\x14\n\x0cservice_name\x18\x04 \x01(\t\x12\x12\n\nstarted_at\x18\x05 \x01(\x03\x12\r\n\x05input\x18\x06 \x01(\x0c\x12\x0f\n\x07attempt\x18\x07 \x01(\x05\x12\x16\n\x0eparent_span_id\x18\x08 \x01(\t\x12\x13\n\x0binstance_id\x18\t \x01(\t"\xe6\x01\n\x11ReportCallRequest\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\n\n\x02fn\x18\x03 \x01(\t\x12\x14\n\x0cservice_name\x18\x04 \x01(\t\x12\x12\n\nstarted_at\x18\x05 \x01(\x03\x12\x13\n\x0bduration_ms\x18\x06 \x01(\x03\x12\x0f\n\x07success\x18\x07 \x01(\x08\x12\r\n\x05error\x18\x08 \x01(\t\x12\r\n\x05input\x18\t \x01(\x0c\x12\x0e\n\x06output\x18\n \x01(\x0c\x12\x0f\n\x07attempt\x18\x0b \x01(\x05\x12\x13\n\x0binstance_id\x18\x0c \x01(\t"\x14\n\x12ReportCallResponse"\xfe\x01\n\x08LogEntry\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\x14\n\x0cservice_name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x14\n\x0ctimestamp_ns\x18\x06 \x01(\x03\x12;\n\nattributes\x18\x07 \x03(\x0b2\'.servicebridge.LogEntry.AttributesEntry\x12\x13\n\x0binstance_id\x18\x08 \x01(\t\x1a1\n\x0fAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"<\n\x10ReportLogRequest\x12(\n\x07entries\x18\x01 \x03(\x0b2\x17.servicebridge.LogEntry"\x13\n\x11ReportLogResponse"\xc1\x01\n\x17RegisterFunctionRequest\x12\x0f\n\x07fn_name\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x10\n\x08endpoint\x18\x04 \x01(\t\x12\x0e\n\x06weight\x18\x05 \x01(\x05\x12\x19\n\x11input_schema_json\x18\x06 \x01(\t\x12\x1a\n\x12output_schema_json\x18\x07 \x01(\t\x12\x11\n\ttransport\x18\x08 \x01(\t"\x1a\n\x18RegisterFunctionResponse"\x91\x01\n\x1cRegisterConsumerGroupRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x19\n\x11retry_policy_json\x18\x04 \x01(\t\x12\x0e\n\x06active\x18\x06 \x01(\x08\x12\x13\n\x0bfilter_expr\x18\x07 \x01(\tJ\x04\x08\x05\x10\x06"\x1f\n\x1dRegisterConsumerGroupResponse"\x90\x01\n\x1aRegisterGroupMemberRequest\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x10\n\x08endpoint\x18\x04 \x01(\t\x12\x0e\n\x06weight\x18\x05 \x01(\x05\x12\x11\n\ttransport\x18\x06 \x01(\t"\x1d\n\x1bRegisterGroupMemberResponse"\xd9\x01\n\x10HeartbeatRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x10\n\x08endpoint\x18\x03 \x01(\t\x12\x13\n\x0bgroup_names\x18\x04 \x03(\t\x12\x16\n\x0efunction_names\x18\x05 \x03(\t\x12\x11\n\ttransport\x18\x06 \x01(\t\x12\x18\n\x0bcpu_percent\x18\x07 \x01(\x02H\x00\x88\x01\x01\x12\x13\n\x06ram_mb\x18\x08 \x01(\x05H\x01\x88\x01\x01B\x0e\n\x0c_cpu_percentB\t\n\x07_ram_mb"\x13\n\x11HeartbeatResponse"\xe8\x01\n\x1bRegisterHttpEndpointRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x15\n\rroute_pattern\x18\x03 \x01(\t\x12\x1b\n\x13request_schema_json\x18\x04 \x01(\t\x12\x1c\n\x14response_schema_json\x18\x05 \x01(\t\x12\x13\n\x0binstance_id\x18\x06 \x01(\t\x12\x10\n\x08endpoint\x18\x07 \x01(\t\x12\x11\n\ttransport\x18\x08 \x01(\t\x12\x17\n\x0fallowed_callers\x18\t \x03(\t"B\n\x1cRegisterHttpEndpointResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x16\n\x0ecanonical_name\x18\x02 \x01(\t"I\n\x1cHeartbeatHttpEndpointRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t"+\n\x1dHeartbeatHttpEndpointResponse\x12\n\n\x02ok\x18\x01 \x01(\x08"d\n!ProvisionWorkerCertificateRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x16\n\x0epublic_key_pem\x18\x02 \x01(\t\x12\x11\n\textra_ips\x18\x03 \x03(\t"F\n"ProvisionWorkerCertificateResponse\x12\x10\n\x08cert_pem\x18\x01 \x01(\t\x12\x0e\n\x06ca_pem\x18\x02 \x01(\t"U\n\x12WorkerSessionHello\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x14\n\x0cmax_inflight\x18\x03 \x01(\x05"b\n\x10WorkerRPCCommand\x12\n\n\x02fn\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08trace_id\x18\x03 \x01(\t\x12\x0f\n\x07span_id\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x05 \x01(\t"\x98\x02\n\x12WorkerEventCommand\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\x12?\n\x07headers\x18\x05 \x03(\x0b2..servicebridge.WorkerEventCommand.HeadersEntry\x12\x10\n\x08trace_id\x18\x06 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x07 \x01(\t\x12\x0f\n\x07attempt\x18\x08 \x01(\x05\x12\x0e\n\x06run_id\x18\t \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"\xd4\x01\n\x14WorkerSessionCommand\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12.\n\x04kind\x18\x02 \x01(\x0e2 .servicebridge.WorkerCommandKind\x12,\n\x03rpc\x18\x03 \x01(\x0b2\x1f.servicebridge.WorkerRPCCommand\x120\n\x05event\x18\x04 \x01(\x0b2!.servicebridge.WorkerEventCommand\x12\x18\n\x10deadline_unix_ms\x18\x05 \x01(\x03"\x9c\x01\n\x1aWorkerSessionCommandResult\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0e\n\x06output\x18\x03 \x01(\x0c\x12\r\n\x05error\x18\x04 \x01(\t\x12\x0b\n\x03ack\x18\x05 \x01(\x08\x12\x16\n\x0eretry_after_ms\x18\x06 \x01(\x05\x12\x15\n\rreject_reason\x18\x07 \x01(\t".\n\x11WorkerSessionPing\x12\x19\n\x11timestamp_unix_ms\x18\x01 \x01(\x03".\n\x11WorkerSessionPong\x12\x19\n\x11timestamp_unix_ms\x18\x01 \x01(\x03"\xa1\x01\n\x16WorkerSessionHeartbeat\x12\x13\n\x0bgroup_names\x18\x01 \x03(\t\x12\x16\n\x0efunction_names\x18\x02 \x03(\t\x12\x10\n\x08endpoint\x18\x03 \x01(\t\x12\x18\n\x0bcpu_percent\x18\x04 \x01(\x02H\x00\x88\x01\x01\x12\x13\n\x06ram_mb\x18\x05 \x01(\x05H\x01\x88\x01\x01B\x0e\n\x0c_cpu_percentB\t\n\x07_ram_mb"\x1c\n\x1aWorkerSessionHttpHeartbeat"\x98\x01\n\x1bWorkerSessionTelemetryStart\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x03 \x01(\t\x12\n\n\x02fn\x18\x04 \x01(\t\x12\x12\n\nstarted_at\x18\x05 \x01(\x03\x12\r\n\x05input\x18\x06 \x01(\x0c\x12\x0f\n\x07attempt\x18\x07 \x01(\x05"\xc6\x01\n\x1cWorkerSessionTelemetryFinish\x12\x10\n\x08trace_id\x18\x01 \x01(\t\x12\x0f\n\x07span_id\x18\x02 \x01(\t\x12\n\n\x02fn\x18\x03 \x01(\t\x12\x12\n\nstarted_at\x18\x04 \x01(\x03\x12\x13\n\x0bduration_ms\x18\x05 \x01(\x03\x12\x0f\n\x07success\x18\x06 \x01(\x08\x12\r\n\x05error\x18\x07 \x01(\t\x12\r\n\x05input\x18\x08 \x01(\x0c\x12\x0e\n\x06output\x18\t \x01(\x0c\x12\x0f\n\x07attempt\x18\n \x01(\x05"E\n\x19WorkerSessionTelemetryLog\x12(\n\x07entries\x18\x01 \x03(\x0b2\x17.servicebridge.LogEntry"F\n\x19WorkerSessionAppendStream\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04data\x18\x03 \x01(\x0c"\xe3\x04\n\x14WorkerSessionRequest\x122\n\x05hello\x18\x01 \x01(\x0b2!.servicebridge.WorkerSessionHelloH\x00\x12C\n\x0ecommand_result\x18\x02 \x01(\x0b2).servicebridge.WorkerSessionCommandResultH\x00\x120\n\x04ping\x18\x03 \x01(\x0b2 .servicebridge.WorkerSessionPingH\x00\x12:\n\theartbeat\x18\x04 \x01(\x0b2%.servicebridge.WorkerSessionHeartbeatH\x00\x12C\n\x0ehttp_heartbeat\x18\x05 \x01(\x0b2).servicebridge.WorkerSessionHttpHeartbeatH\x00\x12E\n\x0ftelemetry_start\x18\x06 \x01(\x0b2*.servicebridge.WorkerSessionTelemetryStartH\x00\x12G\n\x10telemetry_finish\x18\x07 \x01(\x0b2+.servicebridge.WorkerSessionTelemetryFinishH\x00\x12A\n\rtelemetry_log\x18\x08 \x01(\x0b2(.servicebridge.WorkerSessionTelemetryLogH\x00\x12A\n\rappend_stream\x18\t \x01(\x0b2(.servicebridge.WorkerSessionAppendStreamH\x00B\t\n\x07payload"\x8c\x01\n\x15WorkerSessionResponse\x126\n\x07command\x18\x01 \x01(\x0b2#.servicebridge.WorkerSessionCommandH\x00\x120\n\x04pong\x18\x02 \x01(\x0b2 .servicebridge.WorkerSessionPongH\x00B\t\n\x07payload"_\n\x17RegisterWorkflowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12\x0c\n\x04opts\x18\x03 \x01(\t\x12\x14\n\x0cservice_name\x18\x04 \x01(\t"&\n\x18RegisterWorkflowResponse\x12\n\n\x02id\x18\x01 \x01(\t"G\n\x12RunWorkflowRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x0c\x12\x14\n\x0cservice_name\x18\x03 \x01(\t"7\n\x13RunWorkflowResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08trace_id\x18\x02 \x01(\t"*\n\x18CancelWorkflowRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t">\n\x19CancelWorkflowRunResponse\x12\x11\n\tcancelled\x18\x01 \x01(\x08\x12\x0e\n\x06run_id\x18\x02 \x01(\t"\xbd\x01\n\x12RegisterJobRequest\x12\x11\n\tcron_expr\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12\x16\n\x0emisfire_policy\x18\x03 \x01(\t\x12\x13\n\x0btarget_type\x18\x04 \x01(\t\x12\x12\n\ntarget_ref\x18\x05 \x01(\t\x12\x10\n\x08delay_ms\x18\x06 \x01(\x05\x12\x14\n\x0cservice_name\x18\x07 \x01(\t\x12\x19\n\x11retry_policy_json\x18\x08 \x01(\t"!\n\x13RegisterJobResponse\x12\n\n\x02id\x18\x01 \x01(\t"@\n\x13AppendStreamRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04data\x18\x03 \x01(\x0c"\x16\n\x14AppendStreamResponse"E\n\x0fWatchRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x15\n\rfrom_sequence\x18\x03 \x01(\x03"e\n\x0eRunStreamChunk\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04data\x18\x04 \x01(\x0c\x12\x10\n\x08sequence\x18\x05 \x01(\x03\x12\x12\n\nrun_status\x18\x06 \x01(\tJ\x04\x08\x02\x10\x03**\n\x13RegistryMessageKind\x12\x08\n\x04FULL\x10\x00\x12\t\n\x05DELTA\x10\x01*t\n\x11WorkerCommandKind\x12#\n\x1fWORKER_COMMAND_KIND_UNSPECIFIED\x10\x00\x12\x1b\n\x17WORKER_COMMAND_KIND_RPC\x10\x01\x12\x1d\n\x19WORKER_COMMAND_KIND_EVENT\x10\x022\x93\x0f\n\rServiceBridge\x12c\n\x10RegisterFunction\x12&.servicebridge.RegisterFunctionRequest\x1a\'.servicebridge.RegisterFunctionResponse\x12r\n\x15RegisterConsumerGroup\x12+.servicebridge.RegisterConsumerGroupRequest\x1a,.servicebridge.RegisterConsumerGroupResponse\x12l\n\x13RegisterGroupMember\x12).servicebridge.RegisterGroupMemberRequest\x1a*.servicebridge.RegisterGroupMemberResponse\x12N\n\tHeartbeat\x12\x1f.servicebridge.HeartbeatRequest\x1a .servicebridge.HeartbeatResponse\x12o\n\x14RegisterHttpEndpoint\x12*.servicebridge.RegisterHttpEndpointRequest\x1a+.servicebridge.RegisterHttpEndpointResponse\x12r\n\x15HeartbeatHttpEndpoint\x12+.servicebridge.HeartbeatHttpEndpointRequest\x1a,.servicebridge.HeartbeatHttpEndpointResponse\x12\x81\x01\n\x1aProvisionWorkerCertificate\x120.servicebridge.ProvisionWorkerCertificateRequest\x1a1.servicebridge.ProvisionWorkerCertificateResponse\x12b\n\x11OpenWorkerSession\x12#.servicebridge.WorkerSessionRequest\x1a$.servicebridge.WorkerSessionResponse(\x010\x01\x12c\n\x10RegisterWorkflow\x12&.servicebridge.RegisterWorkflowRequest\x1a\'.servicebridge.RegisterWorkflowResponse\x12T\n\x0bRunWorkflow\x12!.servicebridge.RunWorkflowRequest\x1a".servicebridge.RunWorkflowResponse\x12f\n\x11CancelWorkflowRun\x12\'.servicebridge.CancelWorkflowRunRequest\x1a(.servicebridge.CancelWorkflowRunResponse\x12T\n\x0bRegisterJob\x12!.servicebridge.RegisterJobRequest\x1a".servicebridge.RegisterJobResponse\x12V\n\rWatchRegistry\x12#.servicebridge.WatchRegistryRequest\x1a\x1e.servicebridge.RegistryMessage0\x01\x12]\n\x0eLookupFunction\x12$.servicebridge.LookupFunctionRequest\x1a%.servicebridge.LookupFunctionResponse\x12[\n\x0fReportCallStart\x12%.servicebridge.ReportCallStartRequest\x1a!.servicebridge.ReportCallResponse\x12Q\n\nReportCall\x12 .servicebridge.ReportCallRequest\x1a!.servicebridge.ReportCallResponse\x12N\n\tReportLog\x12\x1f.servicebridge.ReportLogRequest\x1a .servicebridge.ReportLogResponse\x12H\n\x07Publish\x12\x1d.servicebridge.PublishRequest\x1a\x1e.servicebridge.PublishResponse\x12W\n\x0cAppendStream\x12".servicebridge.AppendStreamRequest\x1a#.servicebridge.AppendStreamResponse\x12K\n\x08WatchRun\x12\x1e.servicebridge.WatchRunRequest\x1a\x1d.servicebridge.RunStreamChunk0\x012\\\n\x13ServiceBridgeWorker\x12E\n\x06Handle\x12\x1c.servicebridge.HandleRequest\x1a\x1d.servicebridge.HandleResponseB-Z+github.com/service-bridge/go/internal/pb;pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'servicebridge_pb2', _globals)
