# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: controlplane/v1/control_plane.proto
# Protobuf Python Version: 5.27.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    4,
    '',
    'controlplane/v1/control_plane.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from common.v1 import types_pb2 as common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#controlplane/v1/control_plane.proto\x12\x1dservicebridge.controlplane.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x15\x63ommon/v1/types.proto\"\x87\x05\n\x10ReconcileRequest\x12K\n\x08identity\x18\x01 \x01(\x0b\x32\'.servicebridge.common.v1.WorkerIdentityB\x06\xbaH\x03\xc8\x01\x01R\x08identity\x12J\n\tfunctions\x18\x02 \x03(\x0b\x32,.servicebridge.common.v1.FunctionDeclarationR\tfunctions\x12Z\n\x0f\x63onsumer_groups\x18\x03 \x03(\x0b\x32\x31.servicebridge.common.v1.ConsumerGroupDeclarationR\x0e\x63onsumerGroups\x12N\n\x0bhttp_routes\x18\x04 \x03(\x0b\x32-.servicebridge.common.v1.HttpRouteDeclarationR\nhttpRoutes\x12J\n\tworkflows\x18\x05 \x03(\x0b\x32,.servicebridge.common.v1.WorkflowDeclarationR\tworkflows\x12;\n\x04jobs\x18\x06 \x03(\x0b\x32\'.servicebridge.common.v1.JobDeclarationR\x04jobs\x12\x42\n\x07metrics\x18\x07 \x01(\x0b\x32(.servicebridge.common.v1.ResourceMetricsR\x07metrics\x12M\n\x0etransport_mode\x18\x08 \x01(\x0e\x32&.servicebridge.common.v1.TransportModeR\rtransportMode\x12\x12\n\x04zone\x18\t \x01(\tR\x04zone\"^\n\x11ReconcileResponse\x12 \n\x0clease_ttl_ms\x18\x01 \x01(\x03R\nleaseTtlMs\x12\'\n\x0fserver_revision\x18\x02 \x01(\x03R\x0eserverRevision\"\xdd\x01\n\x17IssueCertificateRequest\x12*\n\x0cservice_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0bserviceName\x12(\n\x0binstance_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ninstanceId\x12 \n\x07\x63sr_pem\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06\x63srPem\x12+\n\x11\x61\x64vertise_address\x18\x04 \x01(\tR\x10\x61\x64vertiseAddress\x12\x1d\n\nextra_sans\x18\x05 \x03(\tR\textraSans\"k\n\x18IssueCertificateResponse\x12\x19\n\x08\x63\x65rt_pem\x18\x01 \x01(\tR\x07\x63\x65rtPem\x12\x15\n\x06\x63\x61_pem\x18\x02 \x01(\tR\x05\x63\x61Pem\x12\x1d\n\nexpires_at\x18\x03 \x01(\x03R\texpiresAt\"\xf6\x01\n\x0ePublishRequest\x12\x1d\n\x05topic\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05topic\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\x12T\n\x07headers\x18\x03 \x03(\x0b\x32:.servicebridge.controlplane.v1.PublishRequest.HeadersEntryR\x07headers\x12\x19\n\x08trace_id\x18\x04 \x01(\tR\x07traceId\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"0\n\x0fPublishResponse\x12\x1d\n\nmessage_id\x18\x01 \x01(\tR\tmessageId\"\xc9\x01\n\x16\x45xecuteWorkflowRequest\x12,\n\rworkflow_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0cworkflowName\x12\x14\n\x05input\x18\x02 \x01(\x0cR\x05input\x12\x19\n\x08trace_id\x18\x03 \x01(\tR\x07traceId\x12$\n\x0egroup_trace_id\x18\x04 \x01(\tR\x0cgroupTraceId\x12*\n\x0cservice_name\x18\x05 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0bserviceName\"4\n\x17\x45xecuteWorkflowResponse\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\"S\n\x15\x43\x61ncelWorkflowRequest\x12\"\n\x08trace_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07traceId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"6\n\x16\x43\x61ncelWorkflowResponse\x12\x1c\n\tcancelled\x18\x01 \x01(\x08R\tcancelled\"\xd3\x01\n\x10ProxyCallRequest\x12,\n\rfunction_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0c\x66unctionName\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\x12$\n\x0egroup_trace_id\x18\x03 \x01(\tR\x0cgroupTraceId\x12\x17\n\x07span_id\x18\x04 \x01(\tR\x06spanId\x12\x19\n\x08trace_id\x18\x05 \x01(\tR\x07traceId\x12\x1d\n\ntimeout_ms\x18\x06 \x01(\x05R\ttimeoutMs\"[\n\x11ProxyCallResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x16\n\x06output\x18\x02 \x01(\x0cR\x06output\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\"d\n\x11WatchTraceRequest\x12\"\n\x08trace_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07traceId\x12\x19\n\x08\x66rom_seq\x18\x02 \x01(\x03R\x07\x66romSeq\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\"\xab\x01\n\x10TraceStreamChunk\x12\x10\n\x03seq\x18\x01 \x01(\x03R\x03seq\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x1d\n\nevent_type\x18\x03 \x01(\tR\teventType\x12\x12\n\x04\x64\x61ta\x18\x04 \x01(\x0cR\x04\x64\x61ta\x12!\n\x0ctrace_status\x18\x05 \x01(\tR\x0btraceStatus\x12\x1d\n\ncreated_at\x18\x06 \x01(\x03R\tcreatedAt2\xd3\x06\n\x0c\x43ontrolPlane\x12n\n\tReconcile\x12/.servicebridge.controlplane.v1.ReconcileRequest\x1a\x30.servicebridge.controlplane.v1.ReconcileResponse\x12\x83\x01\n\x10IssueCertificate\x12\x36.servicebridge.controlplane.v1.IssueCertificateRequest\x1a\x37.servicebridge.controlplane.v1.IssueCertificateResponse\x12h\n\x07Publish\x12-.servicebridge.controlplane.v1.PublishRequest\x1a..servicebridge.controlplane.v1.PublishResponse\x12\x80\x01\n\x0f\x45xecuteWorkflow\x12\x35.servicebridge.controlplane.v1.ExecuteWorkflowRequest\x1a\x36.servicebridge.controlplane.v1.ExecuteWorkflowResponse\x12}\n\x0e\x43\x61ncelWorkflow\x12\x34.servicebridge.controlplane.v1.CancelWorkflowRequest\x1a\x35.servicebridge.controlplane.v1.CancelWorkflowResponse\x12n\n\tProxyCall\x12/.servicebridge.controlplane.v1.ProxyCallRequest\x1a\x30.servicebridge.controlplane.v1.ProxyCallResponse\x12q\n\nWatchTrace\x12\x30.servicebridge.controlplane.v1.WatchTraceRequest\x1a/.servicebridge.controlplane.v1.TraceStreamChunk0\x01\x42OZMgithub.com/servicebridge/server-go/internal/pb/controlplane/v1;controlplanev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'controlplane.v1.control_plane_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZMgithub.com/servicebridge/server-go/internal/pb/controlplane/v1;controlplanev1'
  _globals['_RECONCILEREQUEST'].fields_by_name['identity']._loaded_options = None
  _globals['_RECONCILEREQUEST'].fields_by_name['identity']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ISSUECERTIFICATEREQUEST'].fields_by_name['service_name']._loaded_options = None
  _globals['_ISSUECERTIFICATEREQUEST'].fields_by_name['service_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ISSUECERTIFICATEREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_ISSUECERTIFICATEREQUEST'].fields_by_name['instance_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ISSUECERTIFICATEREQUEST'].fields_by_name['csr_pem']._loaded_options = None
  _globals['_ISSUECERTIFICATEREQUEST'].fields_by_name['csr_pem']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHREQUEST'].fields_by_name['topic']._loaded_options = None
  _globals['_PUBLISHREQUEST'].fields_by_name['topic']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXECUTEWORKFLOWREQUEST'].fields_by_name['workflow_name']._loaded_options = None
  _globals['_EXECUTEWORKFLOWREQUEST'].fields_by_name['workflow_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_EXECUTEWORKFLOWREQUEST'].fields_by_name['service_name']._loaded_options = None
  _globals['_EXECUTEWORKFLOWREQUEST'].fields_by_name['service_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CANCELWORKFLOWREQUEST'].fields_by_name['trace_id']._loaded_options = None
  _globals['_CANCELWORKFLOWREQUEST'].fields_by_name['trace_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PROXYCALLREQUEST'].fields_by_name['function_name']._loaded_options = None
  _globals['_PROXYCALLREQUEST'].fields_by_name['function_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WATCHTRACEREQUEST'].fields_by_name['trace_id']._loaded_options = None
  _globals['_WATCHTRACEREQUEST'].fields_by_name['trace_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_RECONCILEREQUEST']._serialized_start=123
  _globals['_RECONCILEREQUEST']._serialized_end=770
  _globals['_RECONCILERESPONSE']._serialized_start=772
  _globals['_RECONCILERESPONSE']._serialized_end=866
  _globals['_ISSUECERTIFICATEREQUEST']._serialized_start=869
  _globals['_ISSUECERTIFICATEREQUEST']._serialized_end=1090
  _globals['_ISSUECERTIFICATERESPONSE']._serialized_start=1092
  _globals['_ISSUECERTIFICATERESPONSE']._serialized_end=1199
  _globals['_PUBLISHREQUEST']._serialized_start=1202
  _globals['_PUBLISHREQUEST']._serialized_end=1448
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_start=1390
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_end=1448
  _globals['_PUBLISHRESPONSE']._serialized_start=1450
  _globals['_PUBLISHRESPONSE']._serialized_end=1498
  _globals['_EXECUTEWORKFLOWREQUEST']._serialized_start=1501
  _globals['_EXECUTEWORKFLOWREQUEST']._serialized_end=1702
  _globals['_EXECUTEWORKFLOWRESPONSE']._serialized_start=1704
  _globals['_EXECUTEWORKFLOWRESPONSE']._serialized_end=1756
  _globals['_CANCELWORKFLOWREQUEST']._serialized_start=1758
  _globals['_CANCELWORKFLOWREQUEST']._serialized_end=1841
  _globals['_CANCELWORKFLOWRESPONSE']._serialized_start=1843
  _globals['_CANCELWORKFLOWRESPONSE']._serialized_end=1897
  _globals['_PROXYCALLREQUEST']._serialized_start=1900
  _globals['_PROXYCALLREQUEST']._serialized_end=2111
  _globals['_PROXYCALLRESPONSE']._serialized_start=2113
  _globals['_PROXYCALLRESPONSE']._serialized_end=2204
  _globals['_WATCHTRACEREQUEST']._serialized_start=2206
  _globals['_WATCHTRACEREQUEST']._serialized_end=2306
  _globals['_TRACESTREAMCHUNK']._serialized_start=2309
  _globals['_TRACESTREAMCHUNK']._serialized_end=2480
  _globals['_CONTROLPLANE']._serialized_start=2483
  _globals['_CONTROLPLANE']._serialized_end=3334
# @@protoc_insertion_point(module_scope)
