# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: registry/v1/registry.proto
# Protobuf Python Version: 5.27.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    4,
    '',
    'registry/v1/registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from common.v1 import types_pb2 as common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aregistry/v1/registry.proto\x12\x19servicebridge.registry.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x15\x63ommon/v1/types.proto\"\x83\x01\n\x10SubscribeRequest\x12%\n\x0e\x66unction_names\x18\x01 \x03(\tR\rfunctionNames\x12%\n\x0eresponse_nonce\x18\x02 \x01(\tR\rresponseNonce\x12!\n\x0c\x65rror_detail\x18\x03 \x01(\tR\x0b\x65rrorDetail\"\xd2\x01\n\x11SubscribeResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x14\n\x05nonce\x18\x02 \x01(\tR\x05nonce\x12\x41\n\x04\x66ull\x18\x03 \x01(\x0b\x32+.servicebridge.registry.v1.RegistrySnapshotH\x00R\x04\x66ull\x12@\n\x05\x64\x65lta\x18\x04 \x01(\x0b\x32(.servicebridge.registry.v1.RegistryDeltaH\x00R\x05\x64\x65ltaB\x08\n\x06update\"\xd8\x01\n\x10RegistrySnapshot\x12X\n\tfunctions\x18\x01 \x03(\x0b\x32:.servicebridge.registry.v1.RegistrySnapshot.FunctionsEntryR\tfunctions\x1aj\n\x0e\x46unctionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.servicebridge.registry.v1.FunctionEndpointsR\x05value:\x02\x38\x01\"\xe6\x01\n\rRegistryDelta\x12O\n\x07upserts\x18\x01 \x03(\x0b\x32\x35.servicebridge.registry.v1.RegistryDelta.UpsertsEntryR\x07upserts\x12\x1a\n\x08removals\x18\x02 \x03(\tR\x08removals\x1ah\n\x0cUpsertsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.servicebridge.registry.v1.FunctionEndpointsR\x05value:\x02\x38\x01\"\\\n\x11\x46unctionEndpoints\x12G\n\tendpoints\x18\x01 \x03(\x0b\x32).servicebridge.registry.v1.WorkerEndpointR\tendpoints\"\xb1\x03\n\x0eWorkerEndpoint\x12\x1a\n\x08\x65ndpoint\x18\x01 \x01(\tR\x08\x65ndpoint\x12M\n\x0etransport_mode\x18\x02 \x01(\x0e\x32&.servicebridge.common.v1.TransportModeR\rtransportMode\x12\x1f\n\x0binstance_id\x18\x03 \x01(\tR\ninstanceId\x12\x16\n\x06weight\x18\x04 \x01(\x05R\x06weight\x12!\n\x0cservice_name\x18\x05 \x01(\tR\x0bserviceName\x12\x12\n\x04zone\x18\x06 \x01(\tR\x04zone\x12*\n\x11input_schema_json\x18\n \x01(\tR\x0finputSchemaJson\x12,\n\x12output_schema_json\x18\x0b \x01(\tR\x10outputSchemaJson\x12\'\n\x0f\x61llowed_callers\x18\x0c \x03(\tR\x0e\x61llowedCallers\x12\x41\n\x06health\x18\x14 \x01(\x0b\x32).servicebridge.registry.v1.EndpointHealthR\x06health\"\xb9\x02\n\x0e\x45ndpointHealth\x12\x1c\n\treachable\x18\x01 \x01(\x08R\treachable\x12$\n\x0elatency_p50_ms\x18\x02 \x01(\x05R\x0clatencyP50Ms\x12$\n\x0elatency_p99_ms\x18\x03 \x01(\x05R\x0clatencyP99Ms\x12\x1d\n\nerror_rate\x18\x04 \x01(\x02R\terrorRate\x12\"\n\rlast_check_at\x18\x05 \x01(\x03R\x0blastCheckAt\x12\x31\n\x14\x63onsecutive_failures\x18\x06 \x01(\x05R\x13\x63onsecutiveFailures\x12G\n\x08\x63\x62_state\x18\x07 \x01(\x0e\x32,.servicebridge.common.v1.CircuitBreakerStateR\x07\x63\x62State\"=\n\rLookupRequest\x12,\n\rfunction_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0c\x66unctionName\"\x98\x02\n\x0eLookupResponse\x12!\n\x0cservice_name\x18\x01 \x01(\tR\x0bserviceName\x12\x17\n\x07\x66n_name\x18\x02 \x01(\tR\x06\x66nName\x12G\n\tendpoints\x18\x03 \x03(\x0b\x32).servicebridge.registry.v1.WorkerEndpointR\tendpoints\x12*\n\x11input_schema_json\x18\x04 \x01(\tR\x0finputSchemaJson\x12,\n\x12output_schema_json\x18\x05 \x01(\tR\x10outputSchemaJson\x12\'\n\x0f\x61llowed_callers\x18\x06 \x03(\tR\x0e\x61llowedCallers2\xdc\x01\n\x0fRegistryService\x12j\n\tSubscribe\x12+.servicebridge.registry.v1.SubscribeRequest\x1a,.servicebridge.registry.v1.SubscribeResponse(\x01\x30\x01\x12]\n\x06Lookup\x12(.servicebridge.registry.v1.LookupRequest\x1a).servicebridge.registry.v1.LookupResponseBGZEgithub.com/servicebridge/server-go/internal/pb/registry/v1;registryv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'registry.v1.registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZEgithub.com/servicebridge/server-go/internal/pb/registry/v1;registryv1'
  _globals['_REGISTRYSNAPSHOT_FUNCTIONSENTRY']._loaded_options = None
  _globals['_REGISTRYSNAPSHOT_FUNCTIONSENTRY']._serialized_options = b'8\001'
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._loaded_options = None
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._serialized_options = b'8\001'
  _globals['_LOOKUPREQUEST'].fields_by_name['function_name']._loaded_options = None
  _globals['_LOOKUPREQUEST'].fields_by_name['function_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SUBSCRIBEREQUEST']._serialized_start=110
  _globals['_SUBSCRIBEREQUEST']._serialized_end=241
  _globals['_SUBSCRIBERESPONSE']._serialized_start=244
  _globals['_SUBSCRIBERESPONSE']._serialized_end=454
  _globals['_REGISTRYSNAPSHOT']._serialized_start=457
  _globals['_REGISTRYSNAPSHOT']._serialized_end=673
  _globals['_REGISTRYSNAPSHOT_FUNCTIONSENTRY']._serialized_start=567
  _globals['_REGISTRYSNAPSHOT_FUNCTIONSENTRY']._serialized_end=673
  _globals['_REGISTRYDELTA']._serialized_start=676
  _globals['_REGISTRYDELTA']._serialized_end=906
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._serialized_start=802
  _globals['_REGISTRYDELTA_UPSERTSENTRY']._serialized_end=906
  _globals['_FUNCTIONENDPOINTS']._serialized_start=908
  _globals['_FUNCTIONENDPOINTS']._serialized_end=1000
  _globals['_WORKERENDPOINT']._serialized_start=1003
  _globals['_WORKERENDPOINT']._serialized_end=1436
  _globals['_ENDPOINTHEALTH']._serialized_start=1439
  _globals['_ENDPOINTHEALTH']._serialized_end=1752
  _globals['_LOOKUPREQUEST']._serialized_start=1754
  _globals['_LOOKUPREQUEST']._serialized_end=1815
  _globals['_LOOKUPRESPONSE']._serialized_start=1818
  _globals['_LOOKUPRESPONSE']._serialized_end=2098
  _globals['_REGISTRYSERVICE']._serialized_start=2101
  _globals['_REGISTRYSERVICE']._serialized_end=2321
# @@protoc_insertion_point(module_scope)
