# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: worker/v1/worker.proto
# Protobuf Python Version: 5.27.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    4,
    '',
    'worker/v1/worker.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16worker/v1/worker.proto\x12\x17servicebridge.worker.v1\x1a\x1b\x62uf/validate/validate.proto\"\xd7\x01\n\rHandleRequest\x12,\n\rfunction_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0c\x66unctionName\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\x12$\n\x0egroup_trace_id\x18\x03 \x01(\tR\x0cgroupTraceId\x12\x17\n\x07span_id\x18\x04 \x01(\tR\x06spanId\x12\x19\n\x08trace_id\x18\x05 \x01(\tR\x07traceId\x12$\n\x0eparent_span_id\x18\x06 \x01(\tR\x0cparentSpanId\"X\n\x0eHandleResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x16\n\x06output\x18\x02 \x01(\x0cR\x06output\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\"\x99\x03\n\x0e\x44\x65liverRequest\x12&\n\ngroup_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\tgroupName\x12\x1d\n\x05topic\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05topic\x12&\n\nmessage_id\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\tmessageId\x12\x18\n\x07\x61ttempt\x18\x04 \x01(\x05R\x07\x61ttempt\x12\x18\n\x07payload\x18\x05 \x01(\x0cR\x07payload\x12N\n\x07headers\x18\x06 \x03(\x0b\x32\x34.servicebridge.worker.v1.DeliverRequest.HeadersEntryR\x07headers\x12$\n\x0egroup_trace_id\x18\x07 \x01(\tR\x0cgroupTraceId\x12\x17\n\x07span_id\x18\x08 \x01(\tR\x06spanId\x12\x19\n\x08trace_id\x18\t \x01(\tR\x07traceId\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x84\x01\n\x0f\x44\x65liverResponse\x12\x10\n\x03\x61\x63k\x18\x01 \x01(\x08R\x03\x61\x63k\x12#\n\rreject_reason\x18\x02 \x01(\tR\x0crejectReason\x12$\n\x0eretry_after_ms\x18\x03 \x01(\x05R\x0cretryAfterMs\x12\x14\n\x05\x65rror\x18\x04 \x01(\tR\x05\x65rror2\xc8\x01\n\rWorkerHandler\x12Y\n\x06Handle\x12&.servicebridge.worker.v1.HandleRequest\x1a\'.servicebridge.worker.v1.HandleResponse\x12\\\n\x07\x44\x65liver\x12\'.servicebridge.worker.v1.DeliverRequest\x1a(.servicebridge.worker.v1.DeliverResponseBCZAgithub.com/servicebridge/server-go/internal/pb/worker/v1;workerv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'worker.v1.worker_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/servicebridge/server-go/internal/pb/worker/v1;workerv1'
  _globals['_HANDLEREQUEST'].fields_by_name['function_name']._loaded_options = None
  _globals['_HANDLEREQUEST'].fields_by_name['function_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_DELIVERREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_DELIVERREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_DELIVERREQUEST'].fields_by_name['group_name']._loaded_options = None
  _globals['_DELIVERREQUEST'].fields_by_name['group_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_DELIVERREQUEST'].fields_by_name['topic']._loaded_options = None
  _globals['_DELIVERREQUEST'].fields_by_name['topic']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_DELIVERREQUEST'].fields_by_name['message_id']._loaded_options = None
  _globals['_DELIVERREQUEST'].fields_by_name['message_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_HANDLEREQUEST']._serialized_start=81
  _globals['_HANDLEREQUEST']._serialized_end=296
  _globals['_HANDLERESPONSE']._serialized_start=298
  _globals['_HANDLERESPONSE']._serialized_end=386
  _globals['_DELIVERREQUEST']._serialized_start=389
  _globals['_DELIVERREQUEST']._serialized_end=798
  _globals['_DELIVERREQUEST_HEADERSENTRY']._serialized_start=740
  _globals['_DELIVERREQUEST_HEADERSENTRY']._serialized_end=798
  _globals['_DELIVERRESPONSE']._serialized_start=801
  _globals['_DELIVERRESPONSE']._serialized_end=933
  _globals['_WORKERHANDLER']._serialized_start=936
  _globals['_WORKERHANDLER']._serialized_end=1136
# @@protoc_insertion_point(module_scope)
