# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v1/types.proto
# Protobuf Python Version: 5.27.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    4,
    '',
    'common/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ommon/v1/types.proto\x12\x17servicebridge.common.v1\x1a\x1b\x62uf/validate/validate.proto\"\xa0\x01\n\x0eWorkerIdentity\x12*\n\x0cservice_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0bserviceName\x12(\n\x0binstance_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ninstanceId\x12\x1a\n\x08\x65ndpoint\x18\x03 \x01(\tR\x08\x65ndpoint\x12\x1c\n\ttransport\x18\x04 \x01(\tR\ttransport\"n\n\x0fResourceMetrics\x12$\n\x0b\x63pu_percent\x18\x01 \x01(\x02H\x00R\ncpuPercent\x88\x01\x01\x12\x1a\n\x06ram_mb\x18\x02 \x01(\x05H\x01R\x05ramMb\x88\x01\x01\x42\x0e\n\x0c_cpu_percentB\t\n\x07_ram_mb\"\xd2\x01\n\x13\x46unctionDeclaration\x12 \n\x07\x66n_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06\x66nName\x12\x16\n\x06weight\x18\x02 \x01(\x05R\x06weight\x12*\n\x11input_schema_json\x18\x03 \x01(\tR\x0finputSchemaJson\x12,\n\x12output_schema_json\x18\x04 \x01(\tR\x10outputSchemaJson\x12\'\n\x0f\x61llowed_callers\x18\x05 \x03(\tR\x0e\x61llowedCallers\"\xeb\x01\n\x18\x43onsumerGroupDeclaration\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x04name\x12!\n\x07pattern\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07pattern\x12\x12\n\x04mode\x18\x03 \x01(\tR\x04mode\x12*\n\x11retry_policy_json\x18\x04 \x01(\tR\x0fretryPolicyJson\x12\x16\n\x06\x61\x63tive\x18\x05 \x01(\x08R\x06\x61\x63tive\x12\x1f\n\x0b\x66ilter_expr\x18\x06 \x01(\tR\nfilterExpr\x12\x16\n\x06weight\x18\x07 \x01(\x05R\x06weight\"\xde\x01\n\x14HttpRouteDeclaration\x12\x16\n\x06method\x18\x01 \x01(\tR\x06method\x12#\n\rroute_pattern\x18\x02 \x01(\tR\x0croutePattern\x12.\n\x13request_schema_json\x18\x03 \x01(\tR\x11requestSchemaJson\x12\x30\n\x14response_schema_json\x18\x04 \x01(\tR\x12responseSchemaJson\x12\'\n\x0f\x61llowed_callers\x18\x05 \x03(\tR\x0e\x61llowedCallers\"]\n\x13WorkflowDeclaration\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1e\n\ndefinition\x18\x02 \x01(\tR\ndefinition\x12\x12\n\x04opts\x18\x03 \x01(\tR\x04opts\"\xf7\x01\n\x0eJobDeclaration\x12\x1b\n\tcron_expr\x18\x01 \x01(\tR\x08\x63ronExpr\x12\x1a\n\x08timezone\x18\x02 \x01(\tR\x08timezone\x12%\n\x0emisfire_policy\x18\x03 \x01(\tR\rmisfirePolicy\x12\x1f\n\x0btarget_type\x18\x04 \x01(\tR\ntargetType\x12\x1d\n\ntarget_ref\x18\x05 \x01(\tR\ttargetRef\x12\x19\n\x08\x64\x65lay_ms\x18\x06 \x01(\x05R\x07\x64\x65layMs\x12*\n\x11retry_policy_json\x18\x07 \x01(\tR\x0fretryPolicyJson*d\n\rTransportMode\x12\x1e\n\x1aTRANSPORT_MODE_UNSPECIFIED\x10\x00\x12\x19\n\x15TRANSPORT_MODE_DIRECT\x10\x01\x12\x18\n\x14TRANSPORT_MODE_PROXY\x10\x02*g\n\x13LoadBalancingPolicy\x12\x12\n\x0eLB_ROUND_ROBIN\x10\x00\x12\x0f\n\x0bLB_WEIGHTED\x10\x01\x12\x18\n\x14LB_LEAST_CONNECTIONS\x10\x02\x12\x11\n\rLB_ZONE_AWARE\x10\x03*C\n\x13\x43ircuitBreakerState\x12\r\n\tCB_CLOSED\x10\x00\x12\x0b\n\x07\x43\x42_OPEN\x10\x01\x12\x10\n\x0c\x43\x42_HALF_OPEN\x10\x02\x42\x43ZAgithub.com/servicebridge/server-go/internal/pb/common/v1;commonv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/servicebridge/server-go/internal/pb/common/v1;commonv1'
  _globals['_WORKERIDENTITY'].fields_by_name['service_name']._loaded_options = None
  _globals['_WORKERIDENTITY'].fields_by_name['service_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WORKERIDENTITY'].fields_by_name['instance_id']._loaded_options = None
  _globals['_WORKERIDENTITY'].fields_by_name['instance_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_FUNCTIONDECLARATION'].fields_by_name['fn_name']._loaded_options = None
  _globals['_FUNCTIONDECLARATION'].fields_by_name['fn_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CONSUMERGROUPDECLARATION'].fields_by_name['name']._loaded_options = None
  _globals['_CONSUMERGROUPDECLARATION'].fields_by_name['name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CONSUMERGROUPDECLARATION'].fields_by_name['pattern']._loaded_options = None
  _globals['_CONSUMERGROUPDECLARATION'].fields_by_name['pattern']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_TRANSPORTMODE']._serialized_start=1375
  _globals['_TRANSPORTMODE']._serialized_end=1475
  _globals['_LOADBALANCINGPOLICY']._serialized_start=1477
  _globals['_LOADBALANCINGPOLICY']._serialized_end=1580
  _globals['_CIRCUITBREAKERSTATE']._serialized_start=1582
  _globals['_CIRCUITBREAKERSTATE']._serialized_end=1649
  _globals['_WORKERIDENTITY']._serialized_start=80
  _globals['_WORKERIDENTITY']._serialized_end=240
  _globals['_RESOURCEMETRICS']._serialized_start=242
  _globals['_RESOURCEMETRICS']._serialized_end=352
  _globals['_FUNCTIONDECLARATION']._serialized_start=355
  _globals['_FUNCTIONDECLARATION']._serialized_end=565
  _globals['_CONSUMERGROUPDECLARATION']._serialized_start=568
  _globals['_CONSUMERGROUPDECLARATION']._serialized_end=803
  _globals['_HTTPROUTEDECLARATION']._serialized_start=806
  _globals['_HTTPROUTEDECLARATION']._serialized_end=1028
  _globals['_WORKFLOWDECLARATION']._serialized_start=1030
  _globals['_WORKFLOWDECLARATION']._serialized_end=1123
  _globals['_JOBDECLARATION']._serialized_start=1126
  _globals['_JOBDECLARATION']._serialized_end=1373
# @@protoc_insertion_point(module_scope)
